==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DepozytPOdsetki.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class DepozytPOdsetki extends GenericDPSObject {
    /**
     * DEPOZYT_P_ODSETKI.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DEPOZYT_P_ODSETKI.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * DEPOZYT_P_ODSETKI.DATA_KSIEGOWANIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataKsiegowania;

    /**
     * DEPOZYT_P_ODSETKI.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_ODSETKI.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_ODSETKI.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_ODSETKI.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * DEPOZYT_P_ODSETKI.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return DEPOZYT_P_ODSETKI.DATA_KSIEGOWANIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataKsiegowania() {
        return dataKsiegowania;
    }

    /**
     * DEPOZYT_P_ODSETKI.DATA_KSIEGOWANIA
     *
     * @param dataKsiegowania
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataKsiegowania(Date dataKsiegowania) {
        this.dataKsiegowania = dataKsiegowania;
    }

    /**
     * @return DEPOZYT_P_ODSETKI.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * DEPOZYT_P_ODSETKI.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPOdsetki other = (DepozytPOdsetki) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getDataKsiegowania() == null ? other.getDataKsiegowania() == null : this.getDataKsiegowania().equals(other.getDataKsiegowania()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getDataKsiegowania() == null) ? 0 : getDataKsiegowania().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", data=").append(data);
        sb.append(", dataKsiegowania=").append(dataKsiegowania);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DepozytPOdsetki.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class DepozytPOdsetki extends GenericDPSObject {
    /**
     * DEPOZYT_P_ODSETKI.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DEPOZYT_P_ODSETKI.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * DEPOZYT_P_ODSETKI.DATA_KSIEGOWANIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataKsiegowania;

    /**
     * DEPOZYT_P_ODSETKI.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DEPOZYT_P_ODSETKI.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DEPOZYT_P_ODSETKI.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DEPOZYT_P_ODSETKI.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * DEPOZYT_P_ODSETKI.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return DEPOZYT_P_ODSETKI.DATA_KSIEGOWANIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataKsiegowania() {
        return dataKsiegowania;
    }

    /**
     * DEPOZYT_P_ODSETKI.DATA_KSIEGOWANIA
     *
     * @param dataKsiegowania
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataKsiegowania(Date dataKsiegowania) {
        this.dataKsiegowania = dataKsiegowania;
    }

    /**
     * @return DEPOZYT_P_ODSETKI.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * DEPOZYT_P_ODSETKI.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DepozytPOdsetki other = (DepozytPOdsetki) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getDataKsiegowania() == null ? other.getDataKsiegowania() == null : this.getDataKsiegowania().equals(other.getDataKsiegowania()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getDataKsiegowania() == null) ? 0 : getDataKsiegowania().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", data=").append(data);
        sb.append(", dataKsiegowania=").append(dataKsiegowania);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}
